.. pyAMPS documentation master file, created by
   sphinx-quickstart on Tue Sep 19 21:21:36 2017.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

pyAMPS's documentation
======================

.. toctree::
   :maxdepth: 2
   
   readme
   installation
   usage
   reference
   model_coefficients
   changelog



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
